==> aliyun-java-sdk-mts-2.7.6-sources.jar: com/aliyuncs/mts/Endpoint.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.mts;

import java.util.HashMap;

public class Endpoint {
    public static HashMap<String, String> endpointMap = new HashMap<String, String>() {
        {
            put("cn-shanghai-internal-test-1", "mts.aliyuncs.com");
            put("cn-beijing-gov-1", "mts.aliyuncs.com");
            put("cn-shenzhen-su18-b01", "mts.aliyuncs.com");
            put("cn-shanghai-inner", "mts.aliyuncs.com");
            put("cn-shenzhen-st4-d01", "mts.aliyuncs.com");
            put("cn-haidian-cm12-c01", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-prod-1", "mts.aliyuncs.com");
            put("cn-north-2-gov-1", "mts.aliyuncs.com");
            put("cn-yushanfang", "mts.aliyuncs.com");
            put("cn-qingdao", "mts.aliyuncs.com");
            put("cn-hongkong-finance-pop", "mts.aliyuncs.com");
            put("cn-qingdao-nebula", "mts.aliyuncs.com");
            put("cn-shanghai-finance-1", "mts.aliyuncs.com");
            put("cn-beijing-finance-pop", "mts.aliyuncs.com");
            put("cn-wuhan", "mts.aliyuncs.com");
            put("cn-zhengzhou-nebula-1", "mts.aliyuncs.com");
            put("rus-west-1-pop", "mts.ap-northeast-1.aliyuncs.com");
            put("cn-shanghai-et15-b01", "mts.aliyuncs.com");
            put("cn-hangzhou-bj-b01", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-test-1", "mts.aliyuncs.com");
            put("eu-west-1-oxs", "mts.ap-northeast-1.aliyuncs.com");
            put("cn-zhangbei-na61-b01", "mts.aliyuncs.com");
            put("cn-beijing-finance-1", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-test-3", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-test-2", "mts.aliyuncs.com");
            put("cn-shenzhen-finance-1", "mts.aliyuncs.com");
            put("me-east-1", "mts.ap-northeast-1.aliyuncs.com");
            put("cn-chengdu", "mts.aliyuncs.com");
            put("cn-hangzhou-test-306", "mts.aliyuncs.com");
            put("cn-shanghai-et2-b01", "mts.aliyuncs.com");
            put("cn-hangzhou-finance", "mts.aliyuncs.com");
            put("cn-beijing-nu16-b01", "mts.aliyuncs.com");
            put("cn-edge-1", "mts.aliyuncs.com");
            put("ap-southeast-2", "mts.ap-northeast-1.aliyuncs.com");
            put("ap-southeast-3", "mts.ap-northeast-1.aliyuncs.com");
            put("cn-fujian", "mts.aliyuncs.com");
            put("us-east-1", "mts.ap-northeast-1.aliyuncs.com");
            put("ap-northeast-2-pop", "mts.ap-northeast-1.aliyuncs.com");
            put("cn-shenzhen-inner", "mts.aliyuncs.com");
            put("cn-zhangjiakou-na62-a01", "mts.aliyuncs.com");
        }
    };

    public static String endpointRegionalType = "regional";
}

==> aliyun-java-sdk-mts-3.3.45-sources.jar: com/aliyuncs/mts/Endpoint.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.mts;

import java.util.HashMap;

public class Endpoint {
    public static HashMap<String, String> endpointMap = new HashMap<String, String>() {
        {
            put("cn-shanghai-internal-test-1", "mts.aliyuncs.com");
            put("cn-beijing-gov-1", "mts.aliyuncs.com");
            put("cn-shenzhen-su18-b01", "mts.aliyuncs.com");
            put("cn-wulanchabu", "mts.aliyuncs.com");
            put("cn-shanghai-inner", "mts.aliyuncs.com");
            put("cn-shenzhen-st4-d01", "mts.aliyuncs.com");
            put("cn-haidian-cm12-c01", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-prod-1", "mts.aliyuncs.com");
            put("cn-north-2-gov-1", "mts.aliyuncs.com");
            put("cn-yushanfang", "mts.aliyuncs.com");
            put("cn-hongkong-finance-pop", "mts.aliyuncs.com");
            put("cn-qingdao-nebula", "mts.aliyuncs.com");
            put("cn-shanghai-finance-1", "mts.aliyuncs.com");
            put("cn-beijing-finance-pop", "mts.aliyuncs.com");
            put("cn-wuhan", "mts.aliyuncs.com");
            put("cn-zhangbei", "mts.aliyuncs.com");
            put("cn-zhengzhou-nebula-1", "mts.aliyuncs.com");
            put("rus-west-1-pop", "mts.aliyuncs.com");
            put("cn-shanghai-et15-b01", "mts.aliyuncs.com");
            put("cn-hangzhou-bj-b01", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-test-1", "mts.aliyuncs.com");
            put("eu-west-1-oxs", "mts.aliyuncs.com");
            put("cn-zhangbei-na61-b01", "mts.aliyuncs.com");
            put("cn-beijing-finance-1", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-test-3", "mts.aliyuncs.com");
            put("cn-hangzhou-internal-test-2", "mts.aliyuncs.com");
            put("cn-shenzhen-finance-1", "mts.aliyuncs.com");
            put("me-east-1", "mts.aliyuncs.com");
            put("cn-chengdu", "mts.aliyuncs.com");
            put("cn-hangzhou-test-306", "mts.aliyuncs.com");
            put("cn-huhehaote-nebula-1", "mts.aliyuncs.com");
            put("cn-shanghai-et2-b01", "mts.aliyuncs.com");
            put("cn-hangzhou-finance", "mts.aliyuncs.com");
            put("cn-beijing-nu16-b01", "mts.aliyuncs.com");
            put("cn-edge-1", "mts.aliyuncs.com");
            put("ap-southeast-2", "mts.aliyuncs.com");
            put("ap-southeast-3", "mts.aliyuncs.com");
            put("cn-fujian", "mts.aliyuncs.com");
            put("us-east-1", "mts.aliyuncs.com");
            put("ap-northeast-2-pop", "mts.aliyuncs.com");
            put("cn-shenzhen-inner", "mts.aliyuncs.com");
            put("cn-zhangjiakou-na62-a01", "mts.aliyuncs.com");
        }
    };

    public static String endpointRegionalType = "regional";
}
